package Perinci::Examples::Bin;

use 5.010001;

our $DATE = '2014-07-03'; # DATE
our $VERSION = '0.03'; # VERSION

1;
# ABSTRACT: Perinci example scripts

__END__

=pod

=encoding UTF-8

=head1 NAME

Perinci::Examples::Bin - Perinci example scripts

=head1 VERSION

This document describes version 0.03 of Perinci::Examples::Bin (from Perl distribution Perinci-Examples-Bin), released on 2014-07-03.

=head1 DESCRIPTION

This distribution contains example scripts in bin/. It is split from
L<Perinci::Examples> so the latter does not need to depend on
L<Perinci::CmdLine>.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Examples-Bin>.

=head1 SOURCE

Source repository is at L<https://github.com/sharyanto/perl-Perinci-Examples-Bin>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Perinci-Examples-Bin>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

Steven Haryanto <stevenharyanto@gmail.com>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2014 by Steven Haryanto.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
